uniform sampler2D baseTexture;
uniform sampler2D normalTexture;
uniform sampler2D heightTexture;
uniform vec2 scaleBias;
varying vec3 EyeVector;
varying vec3 LightVector;


void main(void){
	float height = texture2D(heightTexture, gl_TexCoord[0].st).r;
	float v = height * scaleBias.r - scaleBias.g;
	vec3 eyeVec = normalize(EyeVector);
	vec2 newTexCoord = gl_TexCoord[0].st + (eyeVec.xy * v);

	vec4 baseColor = texture2D(baseTexture, newTexCoord.st);
	vec3 normal = texture2D(normalTexture, newTexCoord.st).rgb * 2.0 - 1.0;
	float dist = length(LightVector);
	vec3 lightVec = normalize(LightVector);
	float nxDir = max(0.0,dot(normal, lightVec));
	vec4 diff = gl_FrontMaterial.diffuse * gl_LightSource[0].diffuse * nxDir;
	float specPower = 0.0;
	if(nxDir != 0.0)
	{
		vec3 halfVec = normalize(eyeVec + lightVec);
		float nxHalf = max(0.0,dot(normal, halfVec));
		specPower = pow(nxHalf, gl_FrontMaterial.shininess);
	}
	vec4 spec = gl_LightSource[0].specular * specPower;
	gl_FragColor = gl_FrontMaterial.ambient * gl_LightSource[0].ambient + diff * baseColor + gl_FrontMaterial.specular *spec;
}

