uniform samplerCube cubeMap;
uniform sampler2DShadow shadowMap;
uniform sampler2D baseTexture;
uniform float cubeMapping;
varying vec4 projCoord;
varying vec3 Normal;
varying vec3 Light;
varying vec3 HalfVector;
varying vec4 reflDir;

void main ()
{
	Normal = normalize(Normal);
	float Diffuse = float(gl_FrontMaterial.diffuse * gl_LightSource[0].diffuse * max(dot(Normal,Light),0.0));
	float Ambient = float(gl_FrontMaterial.ambient * gl_LightSource[0].ambient);
	Ambient += float(gl_LightModel.ambient * gl_FrontMaterial.ambient);
	float Specular = float(gl_FrontMaterial.specular * gl_LightSource[0].specular * pow(max(dot(Normal,HalfVector),0.0), gl_FrontMaterial.shininess));
	
	const float kTransparency = 0.1;
	vec4 color = mix(texture2D(baseTexture, gl_TexCoord[0].xy), textureCube(cubeMap, reflDir.xyz), cubeMapping);

	float rValue = shadow2DProj(shadowMap, projCoord).r;
	rValue = clamp(rValue, 0.0, 1.0);

	vec3 coordPos  = projCoord.xyz / projCoord.w;

	if(coordPos.x >= 0.0 && coordPos.y >= 0.0 && coordPos.x <= 1.0 && coordPos.y <= 1.0 && rValue <= kTransparency)
   	{
		gl_FragColor = color * Ambient;
	}
	else
	{
		if(0.3 < Diffuse)
   		{
			gl_FragColor = color * (Ambient + Diffuse + Specular);
		}
		else
		{
			gl_FragColor = color * (Ambient + Diffuse);
		}
	}
}
